==> elisa-plugins-ugly_0.5.8-1.orig.tar.gz: elisa-plugins-ugly-0.5.8/elisa/plugins/youtube/setup.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Olivier Tilloy <olivier@fluendo.com>

"""
setuptools script for the plugin.
"""

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean, Distribution, build_po

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean, build_po=build_po)

setup(name='elisa-plugin-youtube',
    version='0.1',
    description='Youtube plugin',
    long_description='Youtube resource provider for Elisa',
    license='GPLv3',
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    keywords='',
    install_requires=['elisa-plugin-poblesec'],
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.png', '*.mo', '*.po', '*.conf'],
                  'elisa.plugins.youtube.i18n': ['*/LC_MESSAGES/*.po', '*.pot'],
                  },
    entry_points="""\
    """,
    controller_mappings=[('/poblesec/youtube',
                          'elisa.plugins.youtube.controller:YoutubeListSwitcherController')],
    decorator_mappings=[('/poblesec/video/internet',
                         'elisa.plugins.youtube.controller:youtube_decorator')],
    cmdclass=cmdclass)

==> elisa-plugins-ugly_0.5.15.5.orig.tar.gz: elisa-plugins-ugly-0.5.15.5/elisa/plugins/youtube/setup.py <==
# -*- coding: utf-8 -*-
# Elisa - Home multimedia server
# Copyright (C) 2006-2008 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Elisa with Fluendo's plugins.
#
# The GPL part of Elisa is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Elisa" in the root directory of this distribution package
# for details on that license.
#
# Author: Olivier Tilloy <olivier@fluendo.com>

"""
setuptools script for the plugin.
"""

import os
from setuptools import setup
from elisa.core.utils.dist import find_packages, TrialTest, Clean, Distribution, build_po

packages, package_dir = find_packages(os.path.dirname(__file__))
cmdclass = dict(test=TrialTest, clean=Clean, build_po=build_po)

setup(name='elisa-plugin-youtube',
    version='0.1',
    description='Youtube plugin',
    long_description='Youtube resource provider for Elisa',
    license='GPLv3',
    author='Elisa Developers',
    author_email='elisa@lists.fluendo.com',
    keywords='',
    install_requires=['elisa-plugin-poblesec'],
    namespace_packages=['elisa', 'elisa.plugins'],
    packages=packages,
    package_dir=package_dir,
    package_data={'': ['*.png', '*.mo', '*.po', '*.conf'],
                  'elisa.plugins.youtube.i18n': ['*/LC_MESSAGES/*.po', '*.pot'],
                  },
    entry_points="""\
    [elisa.plugins.search.searchers]
    YoutubeSearcher = elisa.plugins.youtube.searcher:YoutubeSearcher

    [elisa.core.components.resource_provider]
    YoutubeResourceProvider = elisa.plugins.youtube.resource_provider:YoutubeResourceProvider
    """,
    controller_mappings=[('/poblesec/youtube',
                          'elisa.plugins.youtube.controller:YoutubeListSwitcherController'),
                         ('/poblesec/search/results/YoutubeSearcher/videos',
                          'elisa.plugins.youtube.controller:YoutubeListSwitcherController'),
                         ],
    decorator_mappings=[('/poblesec/video/internet',
                         'elisa.plugins.youtube.controller:youtube_decorator'),
                        ('/poblesec/search/videos',
                         'elisa.plugins.youtube.searcher:video_search_result_decorator'),
                        ],
    cmdclass=cmdclass)
